<?php

namespace Blog\Blog\Policies;

use Litepie\User\Contracts\UserPolicy;
use Blog\Blog\Models\BlogCategory;

class BlogCategoryPolicy
{

    /**
     * Determine if the given user can view the blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, BlogCategory $blog_category)
    {
        if ($user->canDo('blog.blog_category.view') && $user->isAdmin()) {
            return true;
        }

        return $blog_category->user_id == user_id() && $blog_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blog.blog_category.create');
    }

    /**
     * Determine if the given user can update the given blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, BlogCategory $blog_category)
    {
        if ($user->canDo('blog.blog_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $blog_category->user_id == user_id() && $blog_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BlogCategory $blog_category)
    {
        return $blog_category->user_id == user_id() && $blog_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BlogCategory $blog_category)
    {
        if ($user->canDo('blog.blog_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blog_category.
     *
     * @param UserPolicy $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BlogCategory $blog_category)
    {
        if ($user->canDo('blog.blog_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
