<?php

namespace Blog\Blog\Policies;

use Litepie\User\Contracts\UserPolicy;
use Blog\Blog\Models\BlogPostBlogTag;

class BlogPostBlogTagPolicy
{

    /**
     * Determine if the given user can view the blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function view(UserPolicy $user, BlogPostBlogTag $blog_post_blog_tag)
    {
        if ($user->canDo('blog.blog_post_blog_tag.view') && $user->isAdmin()) {
            return true;
        }

        return $blog_post_blog_tag->user_id == user_id() && $blog_post_blog_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blog.blog_post_blog_tag.create');
    }

    /**
     * Determine if the given user can update the given blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function update(UserPolicy $user, BlogPostBlogTag $blog_post_blog_tag)
    {
        if ($user->canDo('blog.blog_post_blog_tag.edit') && $user->isAdmin()) {
            return true;
        }

        return $blog_post_blog_tag->user_id == user_id() && $blog_post_blog_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BlogPostBlogTag $blog_post_blog_tag)
    {
        return $blog_post_blog_tag->user_id == user_id() && $blog_post_blog_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BlogPostBlogTag $blog_post_blog_tag)
    {
        if ($user->canDo('blog.blog_post_blog_tag.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blog_post_blog_tag.
     *
     * @param UserPolicy $user
     * @param BlogPostBlogTag $blog_post_blog_tag
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BlogPostBlogTag $blog_post_blog_tag)
    {
        if ($user->canDo('blog.blog_post_blog_tag.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
