<?php

namespace Blog\Blog\Policies;

use Litepie\User\Contracts\UserPolicy;
use Blog\Blog\Models\BlogPost;

class BlogPostPolicy
{

    /**
     * Determine if the given user can view the blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function view(UserPolicy $user, BlogPost $blog_post)
    {
        if ($user->canDo('blog.blog_post.view') && $user->isAdmin()) {
            return true;
        }

        return $blog_post->user_id == user_id() && $blog_post->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blog.blog_post.create');
    }

    /**
     * Determine if the given user can update the given blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function update(UserPolicy $user, BlogPost $blog_post)
    {
        if ($user->canDo('blog.blog_post.edit') && $user->isAdmin()) {
            return true;
        }

        return $blog_post->user_id == user_id() && $blog_post->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BlogPost $blog_post)
    {
        return $blog_post->user_id == user_id() && $blog_post->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BlogPost $blog_post)
    {
        if ($user->canDo('blog.blog_post.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blog_post.
     *
     * @param UserPolicy $user
     * @param BlogPost $blog_post
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BlogPost $blog_post)
    {
        if ($user->canDo('blog.blog_post.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
