<?php

namespace Blog\Blog\Providers;

use Illuminate\Support\ServiceProvider;

class BlogServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'blog');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'blog');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('blog.blog', function ($app) {
            return $this->app->make('Blog\Blog\Blog');
        });

        // Bind BlogCategory to repository
        $this->app->bind(
            'Blog\Blog\Interfaces\BlogCategoryRepositoryInterface',
            \Blog\Blog\Repositories\Eloquent\BlogCategoryRepository::class
        );
        // Bind BlogPost to repository
        $this->app->bind(
            'Blog\Blog\Interfaces\BlogPostRepositoryInterface',
            \Blog\Blog\Repositories\Eloquent\BlogPostRepository::class
        );
        // Bind BlogPostBlogTag to repository
        $this->app->bind(
            'Blog\Blog\Interfaces\BlogPostBlogTagRepositoryInterface',
            \Blog\Blog\Repositories\Eloquent\BlogPostBlogTagRepository::class
        );
        // Bind BlogTag to repository
        $this->app->bind(
            'Blog\Blog\Interfaces\BlogTagRepositoryInterface',
            \Blog\Blog\Repositories\Eloquent\BlogTagRepository::class
        );

        $this->app->register(\Blog\Blog\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Blog\Blog\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['blog.blog'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('blog/blog.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/blog')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/blog')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
