<?php

namespace Blog\Blog\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Blog\Blog\Models\Blog;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Blog\Blog\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/blog/blog_category/*')) {
            Route::bind('blog_category', function ($blog_category) {
                $blog_categoryrepo = $this->app->make('Blog\Blog\Interfaces\BlogCategoryRepositoryInterface');
                return $blog_categoryrepo->findorNew($blog_category);
            });
        }

        if (Request::is('*/blog/blog_post/*')) {
            Route::bind('blog_post', function ($blog_post) {
                $blog_postrepo = $this->app->make('Blog\Blog\Interfaces\BlogPostRepositoryInterface');
                return $blog_postrepo->findorNew($blog_post);
            });
        }

        if (Request::is('*/blog/blog_post_blog_tag/*')) {
            Route::bind('blog_post_blog_tag', function ($blog_post_blog_tag) {
                $blog_post_blog_tagrepo = $this->app->make('Blog\Blog\Interfaces\BlogPostBlogTagRepositoryInterface');
                return $blog_post_blog_tagrepo->findorNew($blog_post_blog_tag);
            });
        }

        if (Request::is('*/blog/blog_tag/*')) {
            Route::bind('blog_tag', function ($blog_tag) {
                $blog_tagrepo = $this->app->make('Blog\Blog\Interfaces\BlogTagRepositoryInterface');
                return $blog_tagrepo->findorNew($blog_tag);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
